@@ -76,13 +76,25 @@ class VaultBaseStep(Step):
     if not clear_text.startswith("daas::"):
       raise Exception("Wrong password!")
     return json.loads(clear_text.replace("daas::", ""))
-
+  
   def unseal(self, keys):
     unseal_response = self.vault.sys.submit_unseal_keys(keys=keys)
     if unseal_response["sealed"] == False:
       return True
     return False
 
+  def get_vault_keys(self, payload, start_fn, prompt_fn):
+    start_fn("Needed a password to decrypt vault root tokens")
+    pwd = prompt_fn("Enter password to decrypt", 5, hide_input=True)
+    with open(self.vault_json_path, 'r') as f:
+      crypted_keys = json.load(f)
+      logger.debug(crypted_keys)
+      payload.vault_iv = crypted_keys['iv']
+      payload.vault_ct = crypted_keys['ct']
+      
+    keys = self.decrypt(payload.vault_ct, payload.vault_iv, pwd)
+    return keys
+
   def run(self, payload:Payload, start_fn:Callable, end_fn:Callable, prompt_fn:Callable) -> Payload:
     raise Exception("Must implement")
 
@@ -191,15 +203,7 @@ class VaultUnsealStep(VaultBaseStep):
     #
     # Unsealing
     #
-    start_fn("Needed a password to decrypt vault root tokens")
-    pwd = prompt_fn("Enter password to decrypt", 5, hide_input=True)
-    with open(self.vault_json_path, 'r') as f:
-      crypted_keys = json.load(f)
-      logger.debug(crypted_keys)
-      payload.vault_iv = crypted_keys['iv']
-      payload.vault_ct = crypted_keys['ct']
-      
-    keys = self.decrypt(payload.vault_ct, payload.vault_iv, pwd)
+    keys = self.get_vault_keys(payload, start_fn, prompt_fn)
     start_fn("Unsealing Vault")
     self.unseal(keys["keys"])
     end_fn("OK")
@@ -217,15 +221,7 @@ class VaultSaveSecretsStep(VaultBaseStep):
     #
     # Load root token
     # 
-    start_fn("Needed a password to decrypt vault root tokens")
-    pwd = prompt_fn("Enter password to decrypt", 5, hide_input=True)
-    with open(self.vault_json_path, 'r') as f:
-      crypted_keys = json.load(f)
-      logger.debug(crypted_keys)
-      payload.vault_iv = crypted_keys['iv']
-      payload.vault_ct = crypted_keys['ct']
-      
-    keys = self.decrypt(payload.vault_ct, payload.vault_iv, pwd)
+    keys = self.get_vault_keys(payload, start_fn, prompt_fn)
     self.vault.token = keys['root_token']
 
     #
